@@ -2,6 +2,7 @@ from __future__ import annotations
 
 import typing as t
 import functools
+import itertools
 from pathlib import Path
 
 import typer
@@ -65,8 +66,19 @@ def _dict_update(to_be_updated: t.MutableMapping, data: t.Mapping):
         to_be_updated[k] = v
 
 
-def _deep_update_fn(to_be_updated: "XConfig", data: "XConfig"):
+def _deep_update_fn(to_be_updated: "XConfig", data: "XConfig", verbose: bool):
+    from pipelime.cli.pretty_print import print_info
+
+    if verbose:
+        print_info("> Merging XConfigs:")
+        print_info(">> Base:")
+        print_info(to_be_updated.to_dict(), pretty=True)
+        print_info(">> To be merged:")
+        print_info(data.to_dict(), pretty=True)
     to_be_updated.deep_update(data, full_merge=True)
+    if verbose:
+        print_info(">> Result:")
+        print_info(to_be_updated.to_dict(), pretty=True)
     return to_be_updated
 
 
@@ -78,11 +90,15 @@ def _process_cfg_or_die(
     output: t.Optional[Path],
     exit_on_error: bool,
     verbose: bool,
+    print_all: bool,
 ) -> t.List["XConfig"]:
     from pipelime.cli.pretty_print import print_error, print_info
     from pipelime.choixe.visitors.processor import ChoixeProcessingError
     from pipelime.cli.pretty_print import print_error
 
+    if verbose:
+        print_info(f"> Processing {cfg_name}...")
+
     try:
         effective_configs = (
             [cfg.process(ctx)]
@@ -91,13 +107,15 @@ def _process_cfg_or_die(
         )
     except ChoixeProcessingError as e:
         if exit_on_error:
-            print_error(f"Invalid {cfg_name}! {e}\nRun with -v to get more info.")
+            print_error(
+                f"Invalid {cfg_name}! {e}\nRun with -vv or more to get more info."
+            )
             raise typer.Exit(1)
         raise e
 
     if verbose:
         pls = "s" if len(effective_configs) != 1 else ""
-        print_info(f"\nFound {len(effective_configs)} {cfg_name}{pls}")
+        print_info(f"> Found {len(effective_configs)} {cfg_name}{pls}")
 
     if len(effective_configs) > 1 and run_all is None:
         if not typer.confirm(
@@ -106,6 +124,11 @@ def _process_cfg_or_die(
         ):
             effective_configs = effective_configs[:1]
 
+    if print_all:
+        for idx, c in enumerate(effective_configs):
+            print_info(f">> {cfg_name} {idx}:")
+            print_info(c.to_dict(), pretty=True)
+
     if output is not None:
         zero_fill = len(str(len(effective_configs) - 1))
         for idx, cfg in enumerate(effective_configs):
@@ -124,33 +147,47 @@ def _process_all(
     output: t.Optional[Path],
     run_all: t.Optional[bool],
     exit_on_error: bool,
-    verbose: bool,
+    verbose: int,
 ):
     from pipelime.cli.pretty_print import print_info
     from pipelime.choixe import XConfig
 
+    if verbose > 1:
+        print_info("\nProcessing configurations:")
+
     # first process with no branch
     effective_configs = [
         _process_cfg_or_die(
-            c, effective_ctx, "configuration", False, output, exit_on_error, verbose
+            c,
+            effective_ctx,
+            "configuration",
+            False,
+            output,
+            exit_on_error,
+            verbose > 1,
+            verbose > 3,
         )
         for c in base_cfg
         if c.to_dict()
     ]
     if effective_configs:
+        # effective_configs = functools.reduce(
+        #     lambda acc, curr: acc + curr, effective_configs
+        # )
         effective_configs = functools.reduce(
-            lambda acc, curr: acc + curr, effective_configs
-        )
-        effective_configs = functools.reduce(
-            lambda acc, curr: _deep_update_fn(acc, curr), effective_configs
+            lambda acc, curr: _deep_update_fn(acc, curr, verbose > 3),
+            itertools.chain.from_iterable(effective_configs),
         )
     else:
         effective_configs = XConfig()
 
-    if verbose:
-        print_info("\nMerged configuration:")
+    if verbose > 2:
+        print_info("\nFinal merged configuration:")
         print_info(effective_configs.to_dict(), pretty=True)
 
+    if verbose > 1:
+        print_info("\nProcessing branches:")
+
     # now process the branches, if any, and check the overall merge
     return _process_cfg_or_die(
         effective_configs,
@@ -159,27 +196,26 @@ def _process_all(
         run_all,
         output,
         exit_on_error,
-        verbose,
+        verbose > 1,
+        verbose > 3,
     )
 
 
-app = typer.Typer(pretty_exceptions_enable=False)
+class VersionCallback:
+    @staticmethod
+    def get_version():
+        import pipelime
+
+        return pipelime.__version__
 
 
 def version_callback(value: bool):
-    from pipelime import __version__
-
     if value:
-        print(__version__)
+        print(VersionCallback.get_version())
         raise typer.Exit()
 
 
-@app.command(
-    add_help_option=False,
-    no_args_is_help=True,
-    context_settings={"allow_extra_args": True, "ignore_unknown_options": True},
-)
-def pl_main(  # noqa: C901
+def pl_main(
     ctx: typer.Context,
     config: t.List[Path] = typer.Option(
         None,
@@ -211,7 +247,7 @@ def pl_main(  # noqa: C901
         help=(
             "One or more yaml/json files with some or all the context parameters. "
             "If `--config` is set and `--context` is not, all files matching "
-            "`context*.[yaml|yml|json]` in the folders of all the "
+            "`*context*.[yaml|yml|json]` in the folders of all the "
             "configuration files will be loaded as the context. "
             "Use `--no-ctx-autoload` to disable this behavior.\n\n"
             "`@@opt` or `@opt` command line options update and override them.\n\n"
@@ -264,7 +300,7 @@ def pl_main(  # noqa: C901
         show_default=False,
         help=(
             (
-                "A pipelime command, ie, a `command-name`, "
+                "A command, ie, a `command-name`, "
                 "a `package.module.ClassName` class path or "
                 "a `path/to/module.py:ClassName` uri (use with care).\n\n"
             )
@@ -280,7 +316,7 @@ def pl_main(  # noqa: C901
     command_args: t.Optional[t.List[str]] = typer.Argument(
         None,
         help=(
-            "\b\nPipelime command arguments:\n"
+            "\b\nExpected command line:\n"
             "- `++opt` and `+opt` are command parameters\n"
             "- `@@opt` and `@opt` are context parameters\n"
             "- after `//` `++opt`, `+opt`, `@@opt`and `@opt` "
@@ -300,15 +336,15 @@ def pl_main(  # noqa: C901
     ),
 ):
     """
-    Pipelime Command Line Interface. Examples:
+    {0} Examples:
 
-    `pipelime list` prints a list of the available commands, sequence operators
+    `{1} list` prints a list of the available commands, sequence operators
     and stages.
 
-    `pipelime help <cmd-op-stg>` prints informations on a specific command, sequence
+    `{1} help <cmd-op-stg>` prints informations on a specific command, sequence
     operator or stage.
 
-    `pipelime <command> [<args>]` runs a pipelime command.
+    `{1} <command> [<args>]` runs a{2} command.
 
     NB: command (++opt) and context (@@opt) arguments with no value are treated as
     TRUE boolean values. Use `false` or `true` to explicitly set a boolean
@@ -385,21 +421,21 @@ def pl_main(  # noqa: C901
         from pipelime.choixe import XConfig
         from pipelime.cli.pretty_print import print_error, print_info, print_warning
 
-        if config and context is None and ctx_autoload:
+        if config and not context and ctx_autoload:
             context = []
             for c in config:
-                for p in c.resolve().parent.glob("context*.*"):
+                for p in c.resolve().parent.glob("*context*.*"):
                     if p.suffix in (".yaml", ".yml", ".json"):
                         context += [p]
 
         if verbose > 0:
 
             def _print_file_list(files: t.Sequence[Path], name: str):
-                if config:
-                    flist = ", ".join(f'"{str(c)}"' for c in config)
+                if files:
+                    flist = ", ".join(f'"{str(c)}"' for c in files)
                     print_info(
                         f"{name.capitalize()} file"
-                        + (f"s: [ {flist} ]" if len(config) > 1 else f": {config[0]}")
+                        + (f"s: [ {flist} ]" if len(files) > 1 else f": {files[0]}")
                     )
                 else:
                     print_info(f"No {name} file")
@@ -422,7 +458,7 @@ def pl_main(  # noqa: C901
             e.rich_print()
             raise typer.Exit(1)
 
-        if verbose > 0:
+        if verbose > 2:
             _print_dict(
                 f"Loaded configuration file{'s' if len(config) > 1 else ''}", base_cfg
             )
@@ -440,24 +476,79 @@ def pl_main(  # noqa: C901
         base_ctx.append(XConfig(data=cmdline_ctx, cwd=Path.cwd()))
 
         # process contexts to resolve imports and local loops
-        effective_ctx = [
-            _process_cfg_or_die(
-                c, None, "context", run_all, output_ctx, True, verbose > 0
-            )
-            for c in base_ctx
-            if c.to_dict()
-        ]
+        if verbose > 2:
+            print_info("\nProcessing context files:")
+
+        def _sum(a: XConfig, b: XConfig) -> XConfig:
+            a = XConfig(data=a.to_dict(), cwd=a.get_cwd(), schema=a.get_schema())
+            a.deep_update(b, full_merge=True)
+            return a
+
+        def _ctx_for_ctx_update(ctx_for_ctx: XConfig, new_ctxs: t.Sequence[XConfig]):
+            for newc in new_ctxs:
+                ctx_for_ctx = _sum(newc, ctx_for_ctx)
+            return ctx_for_ctx
+
+        # use the command line context to process the other contexts
+        effective_ctx = []
+        ctx_for_ctx = base_ctx[-1]
+        for idx, curr_ctx in enumerate(base_ctx):
+            if curr_ctx.to_dict():
+                # the context itself is a valid context
+                curr_ctx_for_ctx = _sum(curr_ctx, ctx_for_ctx)
+
+                if verbose > 3:
+                    print_info(f"[{idx}] context to process:")
+                    print_info(curr_ctx.to_dict(), pretty=True)
+                    print_info(f"[{idx}] context for context")
+                    print_info(curr_ctx_for_ctx.to_dict(), pretty=True)
+                if verbose > 2:
+                    print_info(f"[{idx}] preprocessing...")
+
+                new_ctxs = _process_cfg_or_die(
+                    curr_ctx,
+                    curr_ctx_for_ctx,
+                    "context",
+                    run_all,
+                    None,
+                    True,
+                    verbose > 2,
+                    verbose > 3,
+                )
+                partial_ctx_for_ctx = _ctx_for_ctx_update(ctx_for_ctx, new_ctxs)
+
+                if verbose > 3:
+                    print_info(f"[{idx}] updated context for context")
+                    print_info(partial_ctx_for_ctx.to_dict(), pretty=True)
+                if verbose > 2:
+                    print_info(f"[{idx}] processing self-references...")
+
+                new_ctxs = _process_cfg_or_die(
+                    curr_ctx,
+                    partial_ctx_for_ctx,
+                    "context",
+                    run_all,
+                    None,
+                    True,
+                    verbose > 2,
+                    verbose > 3,
+                )
+                ctx_for_ctx = _ctx_for_ctx_update(ctx_for_ctx, new_ctxs)
+
+                if verbose > 3:
+                    print_info(f"[{idx}] final updated context for context")
+                    print_info(ctx_for_ctx.to_dict(), pretty=True)
+
+                effective_ctx.extend(new_ctxs)
+
         if effective_ctx:
             effective_ctx = functools.reduce(
-                lambda acc, curr: acc + curr, effective_ctx
-            )
-            effective_ctx = functools.reduce(
-                lambda acc, curr: _deep_update_fn(acc, curr), effective_ctx
+                lambda acc, curr: _deep_update_fn(acc, curr, verbose > 3), effective_ctx
             )
         else:
             effective_ctx = XConfig()
 
-        if verbose > 0:
+        if verbose > 1:
             print_info("\nFinal effective context:")
             print_info(effective_ctx.to_dict(), pretty=True)
 
@@ -466,30 +557,30 @@ def pl_main(  # noqa: C901
 
             from pipelime.choixe.visitors.processor import ChoixeProcessingError
 
-            print_info("\n📄 CONFIGURATION AUDIT\n")
+            print_info("\n📄 CONFIGURATION AUDIT")
             for idx, c in enumerate(base_cfg):
                 if len(base_cfg) > 1:
                     name = str(config[idx]) if idx < len(config) else "command line"
-                    print_info(f"*** {name}")
+                    print_info(f"\n*** {name}")
                 inspect_info = c.inspect()
                 for field in fields(inspect_info):
                     value = getattr(inspect_info, field.name)
                     print_info(f"🔍 {field.name}:")
                     if value or isinstance(value, bool):
-                        print_info(value, pretty=True)
+                        print_info(value, pretty=True, indent_guides=False)
 
-            print_info("\n📄 CONTEXT AUDIT\n")
-            print_info(effective_ctx.to_dict(), pretty=True)
+            print_info("\n📄 EFFECTIVE CONTEXT\n")
+            print_info(effective_ctx.to_dict(), pretty=True, indent_guides=False)
             print_info("")
 
             try:
                 effective_configs = _process_all(
-                    base_cfg, effective_ctx, output, run_all, False, verbose > 0
+                    base_cfg, effective_ctx, output, run_all, False, verbose > 2
                 )
             except ChoixeProcessingError as e:
-                from rich.prompt import Confirm, Prompt
+                # from rich.prompt import Confirm, Prompt
 
-                from pipelime.cli.wizard import Wizard
+                # from pipelime.cli.wizard import Wizard
 
                 print_warning("Some variables are not defined in the context.")
                 print_error(f"Invalid configuration! {e}")
@@ -515,18 +606,25 @@ def pl_main(  # noqa: C901
             # if outfile:
             #     new_ctx.save_to(Path(outfile).with_suffix(".yaml"))
 
-            pls = "s" if len(effective_configs) != 1 else ""
+            cfg_size = len(effective_configs)
+            pls = "s" if cfg_size != 1 else ""
             print_info(
-                "🎉 Configuration successfully processed "
-                f"({len(effective_configs)} variant{pls})."
+                f"🎉 Configuration successfully processed ({cfg_size} variant{pls})."
             )
+
+            if verbose > 2:
+                print_info("\nFinal effective configurations:")
+                for idx, cfg in enumerate(effective_configs):
+                    print_info(f"\n*** CONFIGURATION {idx+1}/{cfg_size} ***\n")
+                    print_info(cfg.to_dict(), pretty=True)
+
             raise typer.Exit(0)
         else:
             from pipelime.cli.pretty_print import show_spinning_status
 
             with show_spinning_status("Processing configuration and context..."):
                 effective_configs = _process_all(
-                    base_cfg, effective_ctx, output, run_all, True, verbose > 0
+                    base_cfg, effective_ctx, output, run_all, True, verbose
                 )
 
             cmd_name = command
@@ -534,7 +632,7 @@ def pl_main(  # noqa: C901
             for idx, cfg in enumerate(effective_configs):
                 cfg_dict = cfg.to_dict()
 
-                if verbose > 0:
+                if verbose > 1:
                     print_info(f"\n*** CONFIGURATION {idx+1}/{cfg_size} ***\n")
                     print_info(cfg_dict, pretty=True)
 
@@ -568,42 +666,28 @@ def run_command(command: str, cmd_args: t.Mapping, verbose: int, dry_run: bool):
     from pydantic.error_wrappers import ValidationError
 
     from pipelime.cli.pretty_print import print_info, print_command_outputs
-    from pipelime.cli.utils import get_pipelime_command_cls, time_to_str
+    from pipelime.cli.utils import get_pipelime_command_cls, time_to_str, show_field_alias_valerr
 
     try:
         cmd_cls = get_pipelime_command_cls(command)
     except ValueError:
         raise typer.Exit(1)
 
-    if verbose > 0:
+    if verbose > 2:
         print_info(f"\nCreating command `{command}` with options:")
         print_info(cmd_args, pretty=True)
 
     try:
         cmd_obj = cmd_cls(**cmd_args)
     except ValidationError as e:
-
-        def _replace_alias(val):
-            if isinstance(val, str):
-                for field in cmd_cls.__fields__.values():
-                    if (
-                        field.model_config.allow_population_by_field_name
-                        and field.has_alias
-                        and field.alias == val
-                    ):
-                        return f"{field.name} / {field.alias}"
-            return val
-
-        for err in e.errors():
-            if "loc" in err:
-                err["loc"] = tuple(_replace_alias(l) for l in err["loc"])
+        show_field_alias_valerr(e)
         raise e
 
     if verbose > 0:
         print_info(f"\nCreated command `{command}`:")
         print_info(cmd_obj.dict(), pretty=True)
 
-    if verbose > 0:
+    if dry_run or verbose > 0:
         print_info(f"\nRunning `{command}`...")
 
     start_time = time.perf_counter_ns()
@@ -616,14 +700,66 @@ def run_command(command: str, cmd_args: t.Mapping, verbose: int, dry_run: bool):
     print_command_outputs(cmd_obj)
 
 
-def run_with_extra_modules(*extra_modules):
-    """Run the CLI setting extra modules as if -m was used."""
-
+def _create_typer_app(
+    *,
+    app_name: str = "Pipelime",
+    entry_point: t.Optional[str] = None,
+    app_description: t.Optional[str] = None,
+    version: t.Optional[str] = None,
+    extra_args: t.Sequence[str] = list(),
+):
     import sys
 
-    sys.argv.extend([a for m in extra_modules for a in ("-m", m)])
+    if entry_point is None and len(sys.argv) > 0:
+        entry_point = Path(sys.argv[0]).name
+
+    # if there is no other args, run the app with no args
+    if extra_args and len(sys.argv) > 1:
+        sys.argv.extend(extra_args)
+
+    def _preproc_docs(func):
+        desc = (
+            app_description
+            if app_description
+            else f"{app_name} Command Line Interface."
+        )
+        n_appname = ("n " if app_name[0] in "aeiouAEIOU" else " ") + app_name
+        if desc[-1] != ".":
+            desc += "."
+        func.__doc__ = func.__doc__.format(
+            desc, entry_point or app_name.casefold(), n_appname
+        )
+        return func
+
+    if version is not None:
+        VersionCallback.get_version = lambda: version
+
+    app = typer.Typer(pretty_exceptions_enable=False)
+    app.command(
+        add_help_option=False,
+        no_args_is_help=True,
+        context_settings={"allow_extra_args": True, "ignore_unknown_options": True},
+    )(_preproc_docs(pl_main))
+    return app
+
+
+def run_typer_app(
+    *,
+    app_name: str = "Pipelime",
+    entry_point: t.Optional[str] = None,
+    app_description: t.Optional[str] = None,
+    version: t.Optional[str] = None,
+    extra_args: t.Sequence[str] = list(),
+):
+    app = _create_typer_app(
+        app_name=app_name,
+        entry_point=entry_point,
+        app_description=app_description,
+        version=version,
+        extra_args=extra_args,
+    )
     app()
 
 
 if __name__ == "__main__":
-    app()
+    run_typer_app()
