@@ -9,6 +9,12 @@ from rich import get_console
 from rich import print as rprint
 from rich.pretty import Pretty
 from rich.table import Table, Column
+from rich.text import Text
+from rich.style import Style
+from rich.panel import Panel
+
+if t.TYPE_CHECKING:
+    from pipelime.cli.utils import ActionInfo
 
 
 def _input_icon():
@@ -128,9 +134,22 @@ def print_command_outputs(command: "PipelimeCommand"):  # type: ignore # noqa: E
     print_model_field_values(command.__fields__, command.get_outputs(), _output_icon())
 
 
+def print_actions_short_help(*actions_info: "ActionInfo", show_class_path: bool = True):
+    grid = Table.grid(
+        *([Column(overflow="fold") for _ in range(2 + int(show_class_path))]),
+        padding=(0, 1),
+    )
+    for a in actions_info:
+        col_vals = [escape(a.name)]
+        if show_class_path:
+            col_vals.append(f"[italic grey50]{escape(a.classpath)}[/]")
+        col_vals.append(escape(a.description))
+        grid.add_row(*col_vals)
+    rprint(grid)
+
+
 def print_models_short_help(
-    *model_cls: t.Type[BaseModel],
-    show_class_path: bool = True,
+    *model_cls: t.Type[BaseModel], show_class_path: bool = True
 ):
     grid = Table.grid(
         *([Column(overflow="fold") for _ in range(2 + int(show_class_path))]),
@@ -169,12 +188,11 @@ def print_model_info(
         *cols,
         box=box.SIMPLE_HEAVY,
         title=(
-            f"[bold dark_red]{escape(get_model_title(model_cls))}[/]\n"
-            f"[blue]{escape(_get_signature(model_cls))}[/]\n"
-            f"[italic grey23]{escape(model_docs)}[/]"
+            f"[#5fafff]{_get_signature(model_cls)}[/]"
+            + (f"\n\n[italic grey82]{escape(model_docs)}[/]" if model_docs else "")
         ),
-        caption=escape(get_model_classpath(model_cls)) if show_class_path else None,
-        title_style="on white",
+        title_style="on #293a05",
+        title_justify="left",
         expand=True,
     )
 
@@ -189,6 +207,16 @@ def print_model_info(
         add_blank_row=True,
     )
 
+    grid = Panel(
+        grid,
+        title=f"[dark_orange bold][on #293a05]{escape(get_model_title(model_cls))}[/]",
+        subtitle=(
+            f"[#5fafff][on #293a05]{escape(get_model_classpath(model_cls))}[/]"
+            if show_class_path
+            else None
+        ),
+    )
+
     rprint(grid)
 
 
@@ -214,7 +242,7 @@ def _field_row(
         else:
             field_docs = ""
 
-        field_docs = " ".join(field_docs.split())
+        # field_docs = " ".join(field_docs.split())
 
     has_root_item = ("__root__" in field.outer_type_.__fields__) if is_model else False
     field_outer_type = (
@@ -240,7 +268,7 @@ def _field_row(
     # Field name & alias
     line = [
         (" " * indent)
-        + ("[bold salmon1]" if indent == 0 else "")
+        + ("[bold dark_orange]" if indent == 0 else "")
         + (
             f"{escape(field.name)} / "
             if field.model_config.allow_population_by_field_name and field.has_alias
@@ -310,17 +338,77 @@ def _field_row(
 
 
 def _get_signature(model_cls: t.Type[BaseModel]) -> str:
+    class RichParameter(inspect.Parameter):
+        def __init__(self, *, name, kind, default, annotation):
+            self._name = name
+            self._kind = kind
+            self._default = default
+            self._annotation = annotation
+
+        def __str__(self):
+            kind = self.kind
+            formatted = self._name
+
+            color = "dark_orange"
+            if kind == inspect.Parameter.VAR_POSITIONAL:
+                formatted = "*" + formatted
+            elif kind == inspect.Parameter.VAR_KEYWORD:
+                formatted = "**<any-extra-data>"
+                color = "indian_red"
+
+            formatted = f"[bold {color}]{escape(formatted)}[/]"
+
+            # Add annotation and default value
+            if self._annotation is not inspect._empty:
+                formatted = "{}: {}".format(
+                    formatted,
+                    escape(
+                        inspect.formatannotation(self._annotation).replace(
+                            "NoneType", "None"
+                        )
+                    ),
+                )
+
+            if self._default is not inspect._empty:
+                default_str = escape(repr(self._default))
+                if self._annotation is not inspect._empty:
+                    formatted = "{} = {}".format(formatted, default_str)
+                else:
+                    formatted = "{}={}".format(formatted, default_str)
+
+            return f"\n  {formatted}"
+
+    fullname = {mfield.alias: mfield.name for mfield in model_cls.__fields__.values()}
     excluded = [
         mfield.alias
         for mfield in model_cls.__fields__.values()
         if mfield.field_info.exclude
     ]
+
     sig = inspect.signature(model_cls)
     sig = sig.replace(
-        parameters=[p for p in sig.parameters.values() if p.name not in excluded],
+        parameters=[
+            RichParameter(
+                name=fullname.get(p.name, p.name),
+                kind=p.kind,
+                default=p.default,
+                annotation=p.annotation,
+            )
+            for p in sig.parameters.values()
+            if p.name not in excluded
+        ],
         return_annotation=inspect.Signature.empty,
     )
-    return str(sig)
+
+    sig = (
+        str(sig)
+        .replace("/,", "\n  /,")
+        .replace("*,", "\n  *,")
+        .replace("/)", "\n  /)")
+        .replace("*)", "\n  *)")
+    )
+    sig = sig[:-1] + "\n)"
+    return sig
 
 
 def _is_model(type_):
@@ -333,7 +421,7 @@ def _human_readable_type(field_outer_type):
     tstr = display_as_type(field_outer_type)
     if inspect.isclass(field_outer_type) and issubclass(field_outer_type, Enum):
         tstr += " {" + ", ".join(v.name.lower() for v in field_outer_type) + "}"
-    return tstr
+    return tstr.replace("NoneType", "None")
 
 
 def _recursive_args_flattening(arg):
